library(SpeCond)
data(expressionSpeCondExample)
##Perform the condition specific detection analysis with SpeCond()
generalResult=SpeCond(expressionSpeCondExample, param.detection=NULL,
multitest.correction.method="BY", prefix.file="E", print.hist.pv=TRUE,
fit1=NULL, fit2=NULL, specificOutlierStep1=NULL)
specificResult=generalResult$specificResult
##Produce the general html page results
getFullHtmlSpeCondResult(SpeCondResult=generalResult, param.detection=
specificResult$param.detection, page.name="Example_SpeCond_results",
page.title="Tissue specific results", sort.condition="all", heatmap.profile=TRUE,
heatmap.expression=FALSE, heatmap.unique.profile=FALSE,
expressionMatrix=expressionSpeCondExample)
##Produce the Gene html page results for the first 20 genes using the specificResult object to be able to link
## these pages to the table result in the general html page
specificResult=generalResult$specificResult
genePageInfo=getGeneHtmlPage(expressionSpeCondExample, specificResult, name.index.html=
"index_example_SpeCond_Results.html",outdir="Single_result_pages_example",
gene.html.ids=c(1:20))
##Produce the general html page results
getFullHtmlSpeCondResult(L.specific.result=specificResult$L.specific.result,
param.detection=specificResult$param.detection, page.name="Example_SpeCond_results2",
page.title="Tissue specific results", prefix.file="S2", sort.condition="all",
heatmap.profile=TRUE, heatmap.expression=FALSE, heatmap.unique.profile
=FALSE, expressionMatrix=Mexp, gene.page.info=genePageInfo)
Run the code above in your browser using DataLab